# Active Backlog

This page lists the backlog from oplog owners.
If you have a feature request, please open an issue, as described in [Contribution](contribution.md).

## Code
- Revisit the timing mechanism (performance timer vs clock timer)
- Support custom inheritors

## DevOps (prioritized)

- Justfile
- doc strings to Mkdocs: https://github.com/mkdocstrings/mkdocstrings
- doc string enforcement
- Poetry
- Precommit Hooks
- Check push policy
- Docker
- Dev Container
- Coverage % in badge (currently shows pass/fail)
